require File.expand_path('../../logger', __FILE__)
require File.expand_path('../../client', __FILE__)

module Nucleo
  module Configurations
    module Default
      API_HOST     = "https//api.quicksprout.com".freeze
      USER_AGENT   = ("Nucleo Web Application Gem %s" % [Nucleo::Client::VERSION]).freeze
      MEDIA_TYPE   = "application/json".freeze
      CONTENT_TYPE = "application/json".freeze

      # Return the collection of default options and values
      #
      # @return [Hash] Keys and values of default configuration
      def self.options
        Hash[Nucleo::Configuration.keys.map { |key| [key, __send__(key)] }]
      end

      # Return the ENV access token or nil
      #
      # @return [String, Nil]
      def self.access_token
        ENV['NUCLEO_ACCESS_TOKEN']
      end

      # Return the ENV API Host or the default production
      # API host.
      #
      # @return [String]
      def self.api_host
        ENV.fetch('NUCLEO_API_HOST', API_HOST)
      end

      # Return the ENV Accept header or
      # default constant.
      #
      # @return [String]
      def self.media_type
        ENV.fetch('NUCLEO_MEDIA_TYPE', MEDIA_TYPE)
      end

      # Return the ENV Content-Type header or
      # default constant.
      #
      # @return [String]
      def self.content_type
        ENV.fetch('NUCLEO_CONTENT_TYPE', CONTENT_TYPE)
      end

      # REturn the ENV User-Agent header or
      # default constant.
      #
      # @return [String]
      def self.user_agent
        ENV.fetch('NUCLEO_USER_AGENT', USER_AGENT)
      end

      # Return the default logger to STDOUT
      #
      # @return [Nucleo::Logger] Logger Delegator
      def self.request_logger
        Nucleo::Logger.new(STDOUT)
      end

      # Return the default logger to STDOUT
      #
      # @return [Nucleo::Logger] Logger Delegator
      def self.detailed_logger
        Nucleo::Logger.new(STDOUT)
      end

      # Return the default logger to STDOUT
      #
      # @return [Nucleo::Logger] Logger Delegator
      def self.cache_logger
        Nucleo::Logger.new(STDOUT)
      end

      # Return the default logger to STDOUT
      #
      # @return [Nucleo::Logger] Logger Delegator
      def self.logger
        Nucleo::Logger.new(STDOUT)
      end

      # Returns a set of default connection options
      #
      # @return [Hash] Connection Options
      def self.connection_options
        {
          :headers => {
            :accept       => self.media_type,
            :user_agent   => self.user_agent,
            :content_type => self.content_type
          }
        }
      end
    end
  end
end
