require 'faraday'
require 'faraday/detailed_logger'
require 'faraday_middleware'
require 'delegate'

module Nucleo
  class Connection < SimpleDelegator

    # Decorating the Faraday object
    #
    # @return [Nucleo::Connection ] Faraday Conection Delegator
    def initialize(url, &block)
      @_connection = Faraday.new(url, &block)
    end

    # Return the Net::HTTP default adapter from Faraday
    #
    # @return [Symbol] Default Adapter
    def self.default_adapter
      Faraday.default_adapter
    end

    # Faraday does not provide an HTTP OPTIONS call. Its
    # core library utilizes `options` for RequestOptions.
    #
    # This allows us to perform an HTTP options request
    #
    # @param url [String] The URL for the request
    # @param params [Hash] Request parameters to send
    # @param headers [Hash] Request headers to send
    #
    # @return [Faraday::Response] Faraday Response
    def http_options(url=nil, params=nil, headers=nil)
      @_connection.run_request(:options, url, params, headers)
    end

    # Specify the class for the Delegator
    #
    # @return [Faraday]
    def __getobj__
      @_connection
    end
  end
end
