module Nucleo
  module Models
    module ChangeTypes
      class Base
        include Comparable

        # Return an instance of the Rule Type domain model
        #
        # @param attributes [Hash]
        #
        # @return [Nucleo::Models::RuleType::Base]
        def initialize(attributes={})
          @attributes = attributes
        end

        def <=>(other)
          self.created_at <=> other.created_at
        end

        # Returns the ID of the rule
        #
        # @return [String]
        def id
          @attributes['id']
        end

        # Returns the associated site id
        #
        # @return [String]
        def site_id
          @attributes['site_id']
        end

        # Returns the associated page id
        #
        # @return [String]
        def page_id
          @attributes['page_id']
        end

        # Returns the context of the rule
        #
        # @return [String]
        def context
          @attributes['context']
        end

        # Returns the category of the rule
        #
        # @return [String]
        def category
          @attributes['category']
        end

        # Returns the type of the rule
        #
        # @return [String]
        def type
          @attributes['type']
        end

        # Returns the created at timestamp
        # of the rule.
        #
        # @return [DateTime]
        def created_at
          begin
            DateTime.parse(@attributes['created_at'])
          rescue
            nil
          end
        end

        protected
        def rule
          @attributes.fetch('rule', {})
        end
      end
    end
  end
end
