module Nucleo
  module Models
    class Changes
      include Enumerable

      # Return an instance of the Rules collection domain model
      #
      # @param collection [Array]
      #
      # @return [Nucleo::Models::Changes]
      def initialize(collection)
        @collection = Array(collection)
      end

      def each(&block)
        internal_collection.each(&block)
      end

      def push(args)
        @collection.push(args)
      end

      # Retrieve a rule by the ID.
      #
      # @return [Nucleo::Models::ChangeType]
      def find_by_id(id)
        self.find { |record| record.id == id.to_s }
      end

      private
      def internal_collection
        core_collection = []

        @collection.inject(core_collection) do |collection,record|
          const_name = ['nucleo', 'models', 'change_types', record['category'], record['type']].map(&:camelcase).join('::')

          begin
            collection.push(Object.const_get(const_name).new(record))
          rescue
            Nucleo::Client.configuration.logger.fatal("Could not instantiate: %s" % [const_name])
          end

          collection
        end

        Array(core_collection)
      end
    end
  end
end
