module Nucleo
  module Models
    class Checks
      include Enumerable

      # Return an instance of the Rules collection domain model
      #
      # @param collection [Array]
      #
      # @return [Nucleo::Models::Changes]
      def initialize(collection)
        @collection = Array(collection)
      end

      def each(&block)
        internal_collection.each(&block)
      end

      # Retrieve a check by type
      #
      # @return [Nucleo::Models::ChangeType]
      def find_by_type(type)
        self.find { |record| record.type == type }
      end

      def find_content
        content = self.collect { |r| r.elements.find_content }.flatten.first
        return "" if content.blank?

        content
      end

      def find_image_src
        self.collect { |r| r.elements.find_image_src }.flatten
      end

      private
      def internal_collection
        core_collection = []

        @collection.inject(core_collection) do |collection,record|
          begin
            const_name = ['nucleo', 'models', 'check_types', record['check']].map(&:camelcase).join('::')
            collection.push(Object.const_get(const_name).new(record))
          rescue
            Nucleo::Client.configuration.logger.fatal("Could not instantiate: %s" % [const_name])
          end

          collection
        end

        Array(core_collection)
      end
    end
  end
end
