module Nucleo
  module Models
    module Concerns
      class Count
        attr_reader :count, :min, :max

        # Returns an instance of the Count concern domain model
        #
        # @param total [Integer]
        # @param min [Integer]
        # @param max [Integer]
        #
        # @return [Nucleo::Concerns::Count]
        def initialize(count, min, max)
          @count = count.to_i
          @min   = min.to_i
          @max   = max.to_i
        end

        # Returns true if missing
        #
        # @return [Boolean]
        def missing?
          (self.count < 1)
        end

        # Returns true if multiple
        #
        # @return [Boolean]
        def multiple?
          (self.count > 1)
        end

        # Returns true if too few
        #
        # @return [Boolean]
        def too_few?
          (self.count < self.min)
        end

        # Returns true if there is a max
        #
        # @return [Boolean]
        def max?
          (self.max > 0)
        end

        # Returns true if there is too many
        #
        # @return [Boolean]
        def too_many?
          (self.max? && (self.count > self.max))
        end
      end
    end
  end
end
