module Nucleo
  module Models
    module Concerns
      class Length
        attr_reader :length, :min, :max

        # Returns an instance of the Length concern domain model
        #
        # @param length [Integer]
        # @param min [Integer]
        # @param max [Integer]
        #
        # @return [Nucleo::Concerns::Length]
        def initialize(length, min, max)
          @length = length.to_i
          @min    = min.to_i
          @max    = max.to_i
        end

        # Returns true if there is a max
        #
        # @return [Boolean]
        def max?
          (self.max > 0)
        end

        # Returns true if too short
        #
        # @return [Boolean]
        def too_short?
          (self.length <= self.min)
        end

        # Returns the too short length
        #
        # @return [Integer]
        def too_short_length
          (self.min - self.length)
        end

        # Returns true if too long
        #
        # @return [Boolean]
        def too_long?
          (self.max? && (self.length > self.max))
        end

        # Returns the too long length
        #
        # @return [Integer]
        def too_long_length
          (self.length - self.max)
        end
      end
    end
  end
end
