module Nucleo
  module Models
    class DateRange
      # Returns an instance of the DateRange domain model
      #
      # @param attributes [Hash]
      #
      # @return [Nucleo::Models::DateRange]
      def initialize(attributes={})
        @attributes = attributes
      end

      # Returns the inclusive days for this range
      #
      # @return [Integer]
      def days
        return nil unless both_dates?

        ((self.end_date - self.start_date) + 1).to_i
      end

      # Returns the start date
      #
      # @return [Date,nil]
      def start_date
        begin
          Date.parse(start_date_value)
        rescue
          nil
        end
      end

      # Returns the end date
      #
      # @return [Date,nil]
      def end_date
        begin
          Date.parse(end_date_value)
        rescue
          nil
        end
      end

      private
      def start_date_value
        @attributes['startDate']
      end

      def start_date_value?
        !start_date_value.nil?
      end

      def end_date_value
        @attributes['endDate']
      end

      def end_date_value?
        !end_date_value.nil?
      end

      def both_dates?
        start_date_value? && end_date_value?
      end
    end
  end
end
