module Nucleo
  module Models
    module FeedTypes
      module Analytics
        module Page

          class Pages < Nucleo::Models::FeedTypes::Analytics::Base
            DIMENSION_NAME = 'ga:pageviews'.freeze
            METRIC_NAME    = 'ga:pageviews'.freeze

            # Returns the specific Metric for this page
            #
            # @return [Nucleo::Models::Metric]
            def metric
              params = {
                'metric'         => METRIC_NAME,
                'dimension'      => DIMENSION_NAME,
                'classification' => @attributes['classification'],
                'totals'         => data['totals'],
                'current_period' => data['current_period'],
                'prior_period'   => data['prior_period']
              }

              Nucleo::Models::Metric.new(params)
            end

            # Delegates to the Totals
            #
            # @return [Nucleo::Models::MetricPeriodsTotals]
            def totals
              self.metric.metric_periods.totals
            end

            # Delegates to the Metric Period
            #
            # @return [Nucleo::Models::MetricPeriod]
            def current_period
              self.metric.metric_periods.current_period
            end

            def any?
              self.current_period.rows?
            end

            # Delegates to the Metric Period
            #
            # @return [Nucleo::Models::MetricPeriod]
            def prior_period
              self.metric.metric_periods.prior_period
            end
            alias :previous_period :prior_period
          end

        end
      end
    end
  end
end
