require 'uri'

module Nucleo
  module Models
    module FeedTypes
      module Seo
        module Page

          class ImgAlt < Nucleo::Models::FeedTypes::Seo::Page::Base

            def image_src(site_url = nil)
              url_template = '%{scheme}://%{host}/%{path}?%{query}#%{fragment}'

              if site_url.present?
                begin
                  site_host = URI(site_url).host
                rescue
                  Nucleo::Client.configuration.logger.fatal("Unable to parse site_url %s" % [site_url])
                end
              end

              img = self.element.src
              begin
                url = URI(img)

                # Check if url is a valid http/https url
                if url.kind_of?(URI::HTTP)
                  return url.to_s
                end

                # Attempt to create new url from fragments
                new_url = URI(url_template % {
                  scheme: (url.scheme or 'http'),
                  host: (url.host or site_host),
                  path: url.path,
                  query: url.query,
                  fragment: url.fragment
                })
                return new_url.to_s if new_url.kind_of?(URI::HTTP)

              rescue
                Nucleo::Client.configuration.logger.fatal("Could not validate image url %s" % [img])
              end
            end

            def alt_content
              self.element.alt
            end

            # Returns the class level feed summary title
            #
            # @return [String]
            def self.feed_summary
              "<strong>img alt</strong> feed summary"
            end

            # Delegate to the class level feed summary
            #
            # @return [String]
            def feed_summary
              self.class.feed_summary
            end

            # Returns the headline based on the length of the content
            #
            # @return [String]
            def headline
              "img alt headline"
            end

            # Returns the detailed summary
            #
            # @return [String]
            def long_summary
              "img alts long summary"
            end

            # Returns the short summary
            #
            # @return [String]
            def short_summary
              "Images with <strong>Alt</strong> text are searchable with images search."
            end
          end

        end
      end
    end
  end
end
