require File.expand_path('../metric_periods', __FILE__)

module Nucleo
  module Models
    class Metric
      # Returns an instance of the Metric domain model. This is
      # the core domain model for a specific metric `type` and
      # `classification`.
      #
      # @param attributes [Hash]
      #
      # @return [Nucleo::Models::Metric]
      def initialize(attributes={})
        @attributes = attributes
      end

      # Returns the classification of the metric
      #
      # @return [String]
      def classification
        @attributes['classification']
      end

      # Returns the type of the metric
      #
      # @return [String]
      def metric
        @attributes['metric']
      end

      # Returns the dimension
      #
      # @return [String]
      def dimension
        @attributes['dimension']
      end

      # Returns the metric periods used for comparison
      #
      # @return [Nucleo::Models::MetricPeriods]
      def metric_periods
        params = {
          'metric'         => self.metric,
          'dimension'      => self.dimension,
          'totals'         => @attributes['totals'],
          'current_period' => @attributes['current_period'],
          'prior_period'   => @attributes['prior_period']
        }

        Nucleo::Models::MetricPeriods.new(params)
      end
    end
  end
end
