require File.expand_path('../metric_period_rows', __FILE__)

module Nucleo
  module Models
    class MetricPeriod
      include Comparable

      # Returns an instance of the Metric Period domain model
      #
      # @param attributes [Hash]
      #
      # @return [Nucleo::Models::MetricPeriod]
      def initialize(attributes={})
        @attributes = attributes
      end

      # Implement Comparable
      def <=>(other)
        if self.current?
          1
        elsif self.prior?
          0
        else
          -1
        end
      end

      # Returns the type of the metric
      #
      # @return [String]
      def metric
        @attributes['metric']
      end

      # Returns the dimension
      #
      # @return [String]
      def dimension
        @attributes['dimension']
      end

      # Returns the name of the period
      #
      # @return [String]
      def period_name
        @attributes['period_name']
      end

      # Returns true if this is current
      #
      # @return [Boolean]
      def current?
        'current' == self.period_name
      end

      # Returns true if this is for the prior period
      #
      # @return [Boolean]
      def prior?
        'prior' == self.period_name
      end

      # Returns the totals for this type of metric
      #
      # @return [Integer]
      def totals
        totals_hash.fetch(self.metric, 0).to_i
      end

      # Returns the instance of the DateRange domain model
      #
      # @return [Nucleo::Models::DateRange]
      def date_range
        Nucleo::Models::DateRange.new(@attributes.fetch('date_range', {}))
      end

      # Returns an instance of the MetricPeriodRows domain model
      #
      # @return [Nucleo::Models::MetricPeriodRows]
      def rows
        Nucleo::Models::MetricPeriodRows.new(self.metric, self.dimension, self.period_name, @attributes.fetch('rows', []))
      end

      # Returns true if there are any rows
      #
      # @return [Boolean]
      def rows?
        self.rows.any?
      end

      private
      def totals_hash
        @attributes.fetch('totals', {})
      end
    end
  end
end
