module Nucleo
  module Models
    class MetricPeriodRow
      # Returns an instance of the Metric Period Row domain model
      #
      # @param attributes [Hash]
      #
      # @return [Nucleo::Models::MetricPeriodRow]
      def initialize(attributes={})
        @attributes = attributes
      end

      # Returns the type of the row
      #
      # @return [String]
      def metric
        @attributes['metric']
      end

      # Returns the dimension
      #
      # @return [String]
      def dimension
        @attributes['dimension']
      end

      # Returns the dimension name
      #
      # @return [String]
      def dimension_name
        if self.page?
          self.page.title
        else
          row.fetch(self.dimension, '')
        end
      end

      # Returns the period name
      #
      # @return [String]
      def period_name
        @attributes['period_name']
      end

      # Returns true if this is the current period
      #
      # @return [Boolean]
      def current?
        'current' == self.period_name
      end

      # Returns true if this is the prior period
      #
      # @return [Boolean]
      def prior?
        'prior' == self.period_name
      end

      # Returns an instance of the Page domain model
      #
      # @return [Nucleo::Models::Page]
      def page
        val = row['page']

        return nil if val.nil? || val.empty?

        Nucleo::Models::Page.new(val)
      end

      # Returns true if there is a page
      #
      # @return [Boolean]
      def page?
        !self.page.nil?
      end

      # Return the value for this metric
      #
      # @return [Integer]
      def value
        row.fetch(self.metric, 0).to_i
      end

      # Returns the change
      #
      # @return [Float]
      def change
        row[translated_key_name(:change)].to_f
      end

      # Returns the percent total
      #
      # @return [Float]
      def pct_total
        row[translated_key_name(:pct_total)].to_f
      end
      alias :percent_total :pct_total

      # Returns the rank change
      #
      # @return [Integer]
      def rank_change
        row[translated_key_name(:rank_change)].to_i
      end

      # Returns the rank
      #
      # @return [Integer]
      def rank
        row[translated_key_name(:rank)].to_i
      end

      private
      def translated_key_name(key)
        key = key.to_s

        [self.metric, key].join('_')
      end

      def row
        @attributes.fetch('row', {})
      end
    end
  end
end
