module Nucleo
  module Models
    class MetricPeriodTotals
      # Returns an instance of the Metric Period Totals
      #
      # This is specific to the period being returned.
      #
      # @param attributes [Hash]
      #
      # @return [Nucleo::Models::MetricPeriodTotals]
      def initialize(attributes={})
        @attributes = attributes
      end

      # Returns the type of metric
      #
      # @return [String]
      def metric
        @attributes['metric']
      end

      # Returns the dimension
      #
      # @return [String]
      def dimension
        @attributes['dimension']
      end

      # Returns the period for the totals
      #
      # @return [Hash]
      def period
        @attributes.fetch('period', {})
      end

      # Returns the site change totals
      #
      # @return [Float]
      def site_change
        self.period[translated_key_name(:site_change)].to_f
      end

      # Returns true if there is a site change
      #
      # @return [Boolean]
      def site_change?
        self.site_change > 0
      end

      # Returns the site change percentage
      #
      # @return [Float]
      def site_change_percent
        if self.site_change?
          self.site_change
        else
          (self.site_change * -1)
        end
      end

      # Returns the dimension change
      #
      # @return [Float]
      def dimension_change
        self.period[translated_key_name(:dimension_change)].to_f
      end

      # Returns the site total
      #
      # @return [Float]
      def site
        self.period[translated_key_name(:site)].to_f
      end

      # Returns the dimension percentage of site change
      #
      # @return [Float]
      def dimension_pct_of_site_change
        self.period[translated_key_name(:dimension_pct_of_site_change)].to_f
      end
      alias :dimension_percent_of_site_change :dimension_pct_of_site_change

      # Returns true if there is a dimension percent of site change
      #
      # @return [Boolean]
      def dimension_percent_of_site_change?
        self.dimension_percent_of_site_change > 0
      end

      def dimension_percent_of_site_change_percent
        if self.dimension_percent_of_site_change?
          self.dimension_percent_of_site_change
        else
          (self.dimension_percent_of_site * -1)
        end
      end

      # Returns the dimension percentage of site
      #
      # @return [Float]
      def dimension_pct_of_site
        self.period[translated_key_name(:dimension_pct_of_site)].to_f
      end
      alias :dimension_percent_of_site :dimension_pct_of_site

      # Returns the dimension total
      #
      # @return [Float]
      def dimension
        self.period[translated_key_name(:dimension)].to_f
      end

      private
      def translated_key_name(key)
        key = key.to_s

        [self.metric, key].join('_')
      end
    end
  end
end
