require File.expand_path('../metric_period', __FILE__)
require File.expand_path('../metric_periods_totals', __FILE__)

module Nucleo
  module Models
    class MetricPeriods
      # Returns an instance of the Metric Periods domain models
      #
      # This takes in the `totals`, `current_period`, and `prior_period`
      # and wraps their response bodies in specific objects for comparisons.
      #
      # @param attributes [Hash]
      #
      # @return [Nucleo::Models::MetricPeriods]
      def initialize(attributes={})
        @attributes = attributes
      end

      # Returns the type of metric for period
      #
      # @return [String]
      def type
        @attributes['type']
      end

      # Returns the type of the metric
      #
      # @return [String]
      def metric
        @attributes['metric']
      end

      # Returns the dimension
      #
      # @return [String]
      def dimension
        @attributes['dimension']
      end

      # Returns the metric period totals
      #
      # @return [Nucleo::Models::MetricPeriodTotals]
      def totals
        params = {
          'metric'    => self.metric,
          'dimension' => self.dimension,
          'totals'    => @attributes['totals']
        }

        Nucleo::Models::MetricPeriodsTotals.new(params)
      end

      # Returns the metric period
      #
      # @return [Nucleo::Models::MetricPeriod]
      def current_period
        params = @attributes.fetch('current_period', {}).merge!('metric' => self.metric, 'dimension' => self.dimension, 'period_name' => 'current')
        Nucleo::Models::MetricPeriod.new(params)
      end

      # Returns the prior metric period
      #
      # @return [Nucleo::Models::MetricPeriod]
      def prior_period
        params = @attributes.fetch('prior_period', {}).merge!('metric' => self.metric, 'dimension' => self.dimension, 'period_name' => 'prior')
        Nucleo::Models::MetricPeriod.new(params)
      end
      alias :previous_period :prior_period

      # Returns a metric periods comparisons collection domain model
      #
      # @return [Array]
      def periods_comparisons
        Nucleo::Models::MetricPeriodsComparisons.new(self.current_period, self.prior_period)
      end
    end
  end
end
