require File.expand_path('../metric_period', __FILE__)

module Nucleo
  module Models
    class MetricPeriodsComparison
      include Comparable

      # Creates a new instance of the Metric Periods Comparison domain model.
      #
      # @param attributes [Hash]
      #
      # @return [Nucleo::Models::MetricPeriodsComparison]
      def initialize(attributes={})
        @attributes = attributes
      end

      # Returns the dimension
      #
      # @return [String]
      def dimension
        @attributes['dimension']
      end

      # Returns the current period value
      #
      # @return [Float]
      def current_value
        @attributes['current_value'].to_f
      end

      # Returns the prior period value
      #
      # @return [Float]
      def prior_value
        @attributes['prior_value'].to_f
      end

      # Returns the percent change
      #
      # @return [Integer]
      def change
        @attributes['change'].to_f
      end

      # Returns true if there is no change
      #
      # @return [Boolean]
      def no_change?
        self.change == 0
      end

      # Returns true if there is a positive change
      #
      # @return [Boolean]
      def positive_change?
        self.change > 0
      end

      # Returns true if the change is negative
      #
      # @return [Boolean]
      def negative_change?
        self.change < 0
      end

      # Returns the direcction of change
      #
      # @return [String]
      def direction
        if self.positive_change?
          'up'
        elsif self.no_change?
          'same'
        elsif self.negative_change?
          'down'
        end
      end
    end
  end
end
