require File.expand_path('../metric_periods_comparison', __FILE__)

module Nucleo
  module Models
    class MetricPeriodsComparisons
      include Enumerable

      # Returns a Metrics Comparison domain model
      #
      # @param first_period [Nucleo::Models::MetricPeriod]
      # @param second_period [Nucleo::Models::MetricPeriod]
      #
      # @return [Nucleo::Models::MetricPeriodComparison]
      def initialize(first_period, second_period)
        @first_period  = first_period
        @second_period = second_period
      end

      def each(&block)
        internal_collection.each(&block)
      end

      private
      def internal_collection
        grouped_periods.map do |dimension, periods|
          current_period = periods.find(&:current?)
          prior_period   = periods.find(&:prior?)

          attributes = {
            'dimension'     => dimension,
            'current_value' => 0,
            'prior_value'   => 0,
            'change'        => 0,
          }

          if current_period
            attributes.merge!('current_value' => current_period.value, 'change' => current_period.change)
          end

          if prior_period
            attributes.merge!('prior_value' => prior_period.value)
          end

          Nucleo::Models::MetricPeriodsComparison.new(attributes)
        end
      end

      def grouped_periods
        all_rows.group_by(&:dimension_name)
      end

      def first_period
        @first_period
      end

      def first_period_rows
        first_period.rows
      end

      def second_period
        @second_period
      end

      def second_period_rows
        second_period.rows
      end

      def all_rows
        (first_period_rows.to_a + second_period_rows.to_a)
      end
    end
  end
end
