module Nucleo
  module Models
    class MetricPeriodsTotals
      # Returns an instance of the MetricPeriodsTotals domain model
      #
      # These are the totals across both `current_period`
      # and `prior_period`.
      #
      # @param attributes [Hash]
      #
      # @return [Nucleo::Models::MetricPeriodsTotals]
      def initialize(attributes={})
        @attributes = attributes
      end

      # Returns the metric type for the totals
      #
      # @return [String]
      def metric
        @attributes['metric']
      end

      # Returns the dimension
      #
      # @return [String]
      def dimension
        @attributes['dimension']
      end

      # Returns the current period totals
      #
      # @return [Nucleo::Models::MetricPeriodTotals]
      def current_period
        params = {
          'metric'    => self.metric,
          'dimension' => self.dimension,
          'period'    => @attributes['totals']['current_period']
        }

        Nucleo::Models::MetricPeriodTotals.new(params)
      end

      # Returns the prior period totals
      #
      # @return [Nucleo::Models::MetricPeriodTotals]
      def prior_period
        params = {
          'metric'    => self.metric,
          'dimension' => self.dimension,
          'period'    => @attributes['totals']['prior_period']
        }

        Nucleo::Models::MetricPeriodTotals.new(params)
      end
      alias :previous_period :prior_period
    end
  end
end
