module Nucleo
  module Models
    class PageMetric
      METRIC_NAME = 'ga:pageviews'.freeze

      # Returns an instance of the PageRank domain model
      #
      # @param attributes [Hash]
      #
      # @return [Nucleo::Models::PageRank]
      def initialize(attributes={})
        @attributes = attributes
      end

      # Returns the metric value
      #
      # @return [Integer]
      def value
        @attributes[METRIC_NAME].to_i
      end

      # Returns the change
      #
      # @return [Integer]
      def change
        @attributes[translated_key_name(:change)].to_f
      end

      # Returns the pct total
      #
      # @return [Integer]
      def pct_total
        @attributes[translated_key_name(:pct_total)].to_f
      end

      # Returns the rank
      #
      # @return [Integer]
      def rank
        @attributes[translated_key_name(:rank)].to_i
      end

      # Returns the rank
      #
      # @return [Integer]
      def rank_change
        @attributes[translated_key_name(:rank_change)].to_i
      end

      private
      def translated_key_name(key)
        key = key.to_s

        [METRIC_NAME, key].join('_')
      end
    end
  end
end
