require File.expand_path('../feeds', __FILE__)

module Nucleo
  module Models
    class SiteFeed
      # Returns an instanc eof the Site Feed domain model
      #
      # @param attributes [Hash]
      #
      # @return [Nucleo::Models::SiteFeed]
      def initialize(attributes={})
        @attributes = attributes
      end

      def self.retrieve(id, params={})
        response_body = Nucleo::Requests::SiteFeed.retrieve(id, params)

        self.new(response_body)
      end

      # Returns the Analytics Pages domain model
      #
      # @return [Nucleo::Models::FeedTypes::Analytics::Pages]
      def pages
        if @attributes.has_key?('pages')
          Nucleo::Models::FeedTypes::Analytics::Site::Pages.new(@attributes.fetch('pages', {}))
        else
          nil
        end
      end

      # Returns true if there is an Analytics Pages domain model
      #
      # @return [Boolean]
      def pages?
        self.pages.present?
      end

      # Returns the Metrics as Feeds
      #
      # @return [Nucleo::Models::Feeds]
      def metrics
        Nucleo::Models::Feeds.new(@attributes.fetch('metrics', []))
      end

      # Returns true if there are any Metric feed items
      #
      # @return [Boolean]
      def metrics?
        self.metrics.any?
      end

      # Returns the Alerts as Feeds
      #
      # @return [Nucleo::Models::Feeds]
      def alerts
        Nucleo::Models::Feeds.new(@attributes.fetch('alerts', []))
      end

      # Returns true if there are any alert feed items
      #
      # @return [Boolean]
      def alerts?
        self.alerts.any?
      end

      # Returns the changes as Rules
      #
      # @return [Nucleo::Models::Rules]
      def changes
        Nucleo::Models::Rules.new(@attributes.fetch('changes', []))
      end

      # Returns true if there are any change rules
      #
      # @return [Boolean]
      def changes?
        self.changes.any?
      end
    end
  end
end
