module Nucleo
  module Models
    class Tag
      include Comparable

      def initialize(attributes={})
        @attributes = attributes
      end

      def <=>(other)
        self.length <=> other.length
      end

      # Returns the full tag content
      #
      # @return [String]
      def full_tag
        @attributes['full_tag']
      end
      alias :raw_content :full_tag

      # Returns the tag content
      #
      # @return [String]
      def tag_content
        @attributes['tag_content']
      end
      alias :content :tag_content

      # Returns the content length
      #
      # @return [Integer]
      def content_length
        @attributes['content_length'].to_i
      end
      alias :length :content_length

      # Returns the HTML wrapped snippet
      #
      # @todo: Extract this to a view helper
      #
      # @return [String]
      def snippet
        "<p><code>%s</code></p>" % [CGI.escapeHTML(self.full_tag)]
      end
    end
  end
end
