require File.expand_path('../utilities/status_code_mapper', __FILE__)
require 'faraday_middleware'
require 'delegate'

module Nucleo
  class Response < SimpleDelegator

    def initialize(response)
      @_response = response
    end

    # Returns true if the method is allowed
    #
    # @return [Boolean]
    def allowed?(method)
      self.allowed_methods.include?(method.upcase)
    end

    def on(*statuses, &block)
      status_code_mapper = Nucleo::Utilities::StatusCodeMapper.new(statuses)

      return unless status_code_mapper.includes?(@_response.status)

      if block_given?
        yield(self) and return
      else
        self
      end
    end

    # Specify the class for Simple Delegator
    #
    # @return [Faraday::Response]
    def __getobj__
      @_response
    end

    # Extracts the ALLOW header from the HTTP Response
    #
    # @return [String]
    def allow_header
      self.headers.fetch('allow', '')
    end

    # Returns an array of allowed methods
    #
    # @return [Array]
    def allowed_methods
      self.allow_header.split(',').map(&:strip).map(&:upcase)
    end
  end
end
